query_str: Initialize a query with a specified query string

Description Usage Arguments

View source: R/query_str.R

Description

Initialize a query with a specified query string

Usage

1
query_str(con, str, path = NULL, format = c("list", "xml", "file"))

Arguments

con

A finder connection object from finder_connect().

str

A SOLR query string, e.g. "op=search&q=:&rows=0".

path

An optional directory in which to place downloaded results (required when format="file").

format

One of "list", "xml", "file". In the case of "file", The path to the file will be returned. In all other cases, an object with the fetched data will be returned in the format specified. List results are converted using xml_to_list().


WorldHealthOrganization/finderquery documentation built on Oct. 11, 2020, 12:50 a.m.