xml_to_list: Convert Finder xml result into a more convenient R list...

Description Usage Arguments

View source: R/transforms.R

Description

Convert Finder xml result into a more convenient R list format

Usage

1

Arguments

x

an object of class "xml_document" obtained from query_fetch()


WorldHealthOrganization/finderquery documentation built on Oct. 11, 2020, 12:50 a.m.