Initialize a query with a specified query string
1 |
con |
A finder connection object from |
str |
A SOLR query string, e.g. "op=search&q=:&rows=0". |
path |
An optional directory in which to place downloaded results
(required when |
format |
One of "list", "xml", "file". In the case of "file",
The path to the file will be returned. In all other cases, an object
with the fetched data will be returned in the format specified. List
results are converted using |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.